
#include <ESP8266WiFi.h>
#include <Servo.h>
#include <WiFiUdp.h>
#include <Arduino.h>
#include <OSCMessage.h>
#include <SPI.h>
#include <Wire.h>


WiFiUDP Udp;

const char* ssid = "xxxxxxxx";          // EditThis: The name of your WiFi access point.   
const char* password = "xxxxxxxx";      // EditThis: The password of your WiFi access point.
const unsigned int localPort = 8000;      // The local listening port for UDP packets.

// LED Output
const int bluePin = 14;                // D5 pin at NodeMCU
const int greenPin = 12;               // D6 pin at NodeMCU
const int redPin = 13;                 // D7 pin at NodeMCU


//variables for the LED pins
unsigned int redState = 255;
unsigned int greenState = 255;
unsigned int blueState = 255;


//variables for the Pan and Tilt
unsigned int panVal1 = 0;
unsigned int tiltVal1 = 0;

//assign servos
Servo servo01;
Servo servo02;

// setup configures the underlying hardware for use in the main loop.
void setup() {

    // servo output
    servo01.attach(2);   //D4 pin at NodeMCU
    servo02.attach(0);   //D3 pin at NodeMCU

  
  Serial.begin(9600);
  Serial.print("WiFi");

  // Prevent need for powercyle after upload.
  WiFi.disconnect();

  // Use DHCP to connect and obtain IP Address.
  WiFi.mode(WIFI_STA);
  WiFi.begin(ssid, password);

  // Wait until we have connected to the WiFi AP.
  while (WiFi.status() != WL_CONNECTED) {
     delay(500);
     Serial.print(".");
  }

  // Init UDP to broadcast OSC messages.
  Udp.begin(localPort);
  Serial.println(" Connected!");

  
}

void OSCrender( OSCMessage &msg) { 
                                redState=(uint8_t)msg.getFloat(0),
                                analogWrite(redPin, redState),
                                greenState=(uint8_t)msg.getFloat(1),
                                analogWrite(greenPin, greenState), 
                                blueState=(uint8_t)msg.getFloat(2),
                                analogWrite(bluePin, blueState), 
                                panVal1=(uint8_t)msg.getInt(3),
                                servo01.write(panVal1), 
                                tiltVal1=(uint8_t)msg.getInt(4),
                                servo02.write(tiltVal1);
                                
  }
 // passes OSC bundle to OSCRender and reports 'updating' to serial monitor
void update(OSCMessage &msg) {
  Serial.println("updating");
  OSCrender( msg);
}

// loop executes over and over on the microcontroller. Reads messages from OSC
// and updates OSC receive array accordingly.
void loop() {
  OSCMessage msg;
  int size = Udp.parsePacket();

  if (size > 0) {
    while (size--) {
      msg.fill(Udp.read());
    }
    if (!msg.hasError()) {
      msg.dispatch("/nodemcu/1", update);

    } else {
      OSCErrorCode error = msg.getError();
      Serial.print("error: ");
      Serial.println(error);
    }
  }
}
